@@ -6,6 +6,7 @@ var _sha256Js = require("@aws-crypto/sha256-js");
 var _abortController = require("@aws-sdk/abort-controller");
 var _credentialProviderNode = require("@aws-sdk/credential-provider-node");
 var _nodeHttpHandler = require("@aws-sdk/node-http-handler");
+var _zlib = require("zlib");
 /*
  * Copyright OpenSearch Contributors
  * SPDX-License-Identifier: Apache-2.0
@@ -46,7 +47,7 @@ class HttpAmazonESConnector extends HttpConnector {
       } = await this.httpClient.handle(request, {
         abortSignal: controller.signal
       });
-      const body = await this.streamToString(response.body);
+      const body = await this.streamToString(response.body, response.headers);
       this.log.trace(params.method, reqParams, params.body, body, response.statusCode);
       cb(null, body, response.statusCode, response.headers);
     } catch (err) {
@@ -56,12 +57,19 @@ class HttpAmazonESConnector extends HttpConnector {
   }
 
   // Helper method to convert readable stream to string
-  streamToString(stream) {
+  streamToString(stream, headers = {}) {
     return new Promise((resolve, reject) => {
+      const contentEncoding = headers['content-encoding'] || headers['Content-Encoding'];
+      let targetStream = stream;
+      if (contentEncoding === 'gzip') {
+        targetStream = stream.pipe((0, _zlib.createGunzip)());
+      } else if (contentEncoding === 'deflate') {
+        targetStream = stream.pipe((0, _zlib.createInflate)());
+      }
       const chunks = [];
-      stream.on('data', chunk => chunks.push(chunk));
-      stream.on('error', reject);
-      stream.on('end', () => resolve(Buffer.concat(chunks).toString('utf8')));
+      targetStream.on('data', chunk => chunks.push(chunk));
+      targetStream.on('error', reject);
+      targetStream.on('end', () => resolve(Buffer.concat(chunks).toString('utf8')));
     });
   }
   getAWSCredentials(reqParams) {
